@@ -26,7 +26,7 @@ def test_data() -> pd.DataFrame:
 
 def test_interpolate_middle(test_data: pd.DataFrame):
     df, df_out = test_data
-    interpolated_t = interpolation(df['t'].to_numpy()).interpolate()
+    interpolated_t = interpolation(df['t']).interpolate()
     df['t'] = interpolated_t
     df['t'] = df['t'].astype(int64)
     assert_frame_equal(df, df_out)
